==> question2answer-1.3-language-ru.zip: ru/qa-lang-misc.php <==
<?php
	
/*
	Question2Answer 1.3 (c) 2010, Gideon Greenspan

	http://www.question2answer.org/

	
	File: qa-lang-misc.php
	Version: 1.3
	Date: 2010-11-27 12:12:11 GMT
	Description: Miscellaneous language phrases


	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'block_ip_button' => 'Блокировать IP-адрес',
		'captcha_confirm_fix' => 'Чтобы не вводить капчу в будущем, ^5подтвердите^6 свой адрес электронной почты.',
		'captcha_error' => 'Подтвердите, пожалуйста, что Вы не бот',
		'captcha_label' => 'Анти-спам проверка:',
		'captcha_login_fix' => 'Чтобы не вводить капчу в будущем, ^1войдите^2 или ^3зарегистрируйтесь^4.',
		'feed_a_edited_prefix' => 'Редактирование ответа: ',
		'feed_a_prefix' => 'Ответ на вопрос: ',
		'feed_c_edited_prefix' => 'Редактирование комментария: ',
		'feed_c_prefix' => 'Комментарии: ',
		'feed_edited_prefix' => 'Редактирование: ',
		'feed_not_found' => 'Feed не найден',
		'feedback_email' => 'Ваш e-mail: (необязательно)',
		'feedback_empty' => 'Пожалуйста, напишите здесь Ваши замечания и предложения',
		'feedback_message' => 'Ваши замечания и предложения по улучшению сервиса ^:',
		'feedback_name' => 'Ваше имя: (необязательно)',
		'feedback_sent' => 'Ваше сообщение было отправлено. Спасибо.',
		'feedback_title' => 'Отправить отзыв',
		'host_name' => 'Имя хоста:',
		'matches_blocked_ips' => 'Заблокированные IP-адреса:',
		'no_activity_from_x' => 'Нет активности с ^',
		'recent_activity_from_x' => 'Последние действия с ^',
		'unblock_ip_button' => 'Разблокировать IP-адрес',
		'site_in_maintenance' => 'Сайт в настоящий момент закрыт для пользователей. Зайдите, пожалуйста, попозже.',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/

==> question2answer-1.4-language-ru.zip: ru/qa-lang-misc.php <==
<?php
	
/*
	Question2Answer 1.4.1 (c) 2011, Gideon Greenspan

	http://www.question2answer.org/

    File: qa-lang/ru/qa-lang-misc.php
	Version: 1.4.1
	Date: 2011-08-20
	Description: Русификация Question2Answer 1.4
	Translation: Starozhuk Anatoliy / http://facknet.ru/ 

	This program is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 2
	of the License, or (at your option) any later version.
	
	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	More about this license: http://www.question2answer.org/license.php
*/

	return array(
		'block_ip_button' => 'Блокировать IP-адрес',
		'browse_categories' => 'Обзор категории',
		'captcha_confirm_fix' => 'Чтобы не вводить капчу в будущем, ^5подтвердите^6 свой адрес электронной почты.',
		'captcha_error' => 'Подтвердите, пожалуйста, что Вы не бот',
		'captcha_label' => 'Анти-спам проверка:',
		'captcha_login_fix' => 'Чтобы не вводить капчу в будущем, ^1войдите^2 или ^3зарегистрируйтесь^4.',
		'feed_a_edited_prefix' => 'Редактирование ответа: ',
		'feed_a_prefix' => 'Ответ на вопрос: ',
		'feed_c_edited_prefix' => 'Редактирование комментария: ',
		'feed_c_prefix' => 'Комментарии: ',
		'feed_edited_prefix' => 'Редактирование: ',
		'feed_not_found' => 'Feed не найден',
		'feedback_email' => 'Ваш e-mail: (необязательно)',
		'feedback_empty' => 'Пожалуйста, напишите здесь Ваши замечания и предложения',
		'feedback_message' => 'Ваши замечания и предложения по улучшению сервиса ^:',
		'feedback_name' => 'Ваше имя: (необязательно)',
		'feedback_sent' => 'Ваше сообщение было отправлено. Спасибо.',
		'feedback_title' => 'Отправить отзыв',
		'hide_all_ip_button' => 'Скрыть все сообщения от этого IP',
		'host_name' => 'Имя хоста:',
		'matches_blocked_ips' => 'Заблокированные IP-адреса:',
		'message_empty' => 'Пожалуйста, введите ваше сообщение, чтобы отправить этому пользователю',
		'message_explanation' => 'Это уведомление будет передано от ^. Ваш электронный адрес не будет раскрыт, если вы не включить его в сообщение.',
		'message_for_x' => 'Ваше сообщение ^:',
		'message_limit' => 'Слишком много частных сообщений, отправленных - попробуйте еще раз через час',
		'message_must_login' => 'Пожалуйста ^1войдите^2 или ^3зарегестрируйтесь^4 что бы отправить личное сообщение.',
		'message_sent' => 'Ваше личное сообщение было послано',
		'no_activity_from_x' => 'Нет активности с ^',
		'private_message_title' => 'Отправить личное сообщение',
		'recent_activity_from_x' => 'Последние действия с ^',
		'site_in_maintenance' => 'Сайт в настоящий момент закрыт для пользователей. Зайдите, пожалуйста, попозже.',
		'unblock_ip_button' => 'Разблокировать IP-адрес',
	);
	

/*
	Omit PHP closing tag to help avoid accidental output
*/
